@@ -76,7 +76,7 @@ class Connections(object):
             connection = Connection(self.trainml, con_type, con_id)
             con_task = asyncio.create_task(connection._validate_entity())
             con_tasks.append(con_task)
-        await asyncio.gather(*con_tasks)
+        await asyncio.gather(*con_tasks, return_exceptions=True)
         await self.cleanup_containers(project=self.trainml.project)
         logging.info("Finish cleanup connections")
 
@@ -194,9 +194,11 @@ class Connection:
             self._entity = await self.trainml.jobs.get(self.id)
         elif self.type == "model":
             self._entity = await self.trainml.models.get(self.id)
+        elif self.type == "checkpoint":
+            self._entity = await self.trainml.checkpoints.get(self.id)
         else:
             raise TypeError(
-                "Connection type must be in: ['dataset', 'model', 'job']"
+                "Connection type must be in: ['dataset', 'model', 'checkpoint', 'job']"
             )
 
     async def _download_connection_details(self):
@@ -402,9 +404,9 @@ class Connection:
         with open(f"{self._dir}/vpn_id", "w") as f:
             f.write(vpn_container.id)
 
-        cleanup_task = asyncio.create_task(
-            self.trainml.connections.cleanup_connections()
-        )
+        # cleanup_task = asyncio.create_task(
+        #     self.trainml.connections.cleanup_connections()
+        # )
 
         count = 0
         while count <= 30:
@@ -420,7 +422,7 @@ class Connection:
             raise ConnectionError(f"Unable to connect {self.type} {self.id}")
         self._status = STATUSES.get("CONNECTED")
         logging.info(f"Connection Successful.")
-        await cleanup_task
+        # await cleanup_task
         logging.debug(f"Completed start {self.type} connection {self.id}")
 
     async def stop(self):
